@@ -177,6 +177,38 @@ class ArtistsDatabase:
                 result = sql.execute(request % select, genres)
             return [(row[0], row[1], row[2]) for row in result]
 
+    def get_all(self, genre_ids=[]):
+        """
+            Get all available artists
+            @param genre ids as [int]
+            @return [int, str, str]
+        """
+        if App().settings.get_value("show-artist-sort"):
+            select = "artists.rowid, artists.sortname, artists.sortname"
+        else:
+            select = "artists.rowid, artists.name, artists.sortname"
+        with SqlCursor(App().db) as sql:
+            result = []
+            if not genre_ids or genre_ids[0] == Type.ALL:
+                # Only artist that really have an album
+                result = sql.execute(
+                    "SELECT DISTINCT %s FROM artists\
+                                  ORDER BY artists.sortname\
+                                  COLLATE NOCASE COLLATE LOCALIZED" % select)
+            else:
+                genres = tuple(genre_ids)
+                request = "SELECT DISTINCT %s\
+                           FROM artists, tracks, track_genres, track_artists\
+                           WHERE artists.rowid=track_artists.artist_id\
+                           AND tracks.rowid=track_artists.track_id\
+                           AND track_genres.track_id=tracks.rowid AND ("
+                for genre_id in genre_ids:
+                    request += "track_genres.genre_id=? OR "
+                request += "1=0) ORDER BY artists.sortname\
+                            COLLATE NOCASE COLLATE LOCALIZED"
+                result = sql.execute(request % select, genres)
+            return [(row[0], row[1], row[2]) for row in result]
+
     def get_ids(self, genre_ids=[]):
         """
             Get all available album artists
@@ -221,17 +253,24 @@ class ArtistsDatabase:
                 return bool(v[0])
             return False
 
-    def search(self, string):
+    def search(self, searched):
         """
             Search for artists looking like string
             @param string
             @return Array of id as int
         """
+        no_accents = noaccents(searched)
         with SqlCursor(App().db) as sql:
-            result = sql.execute("SELECT artists.rowid FROM artists\
-                                  WHERE noaccents(artists.name) LIKE ?\
-                                  LIMIT 25", ("%" + noaccents(string) + "%",))
-            return list(itertools.chain(*result))
+            items = []
+            for filter in [(no_accents + "%",),
+                           ("%" + no_accents,),
+                           ("%" + no_accents + "%",)]:
+                result = sql.execute("SELECT artists.rowid\
+                                      FROM artists\
+                                      WHERE noaccents(name) LIKE ? LIMIT 25",
+                                     filter)
+                items += list(itertools.chain(*result))
+            return items
 
     def count(self):
         """
