@@ -48,11 +48,13 @@ class ViewType:
     SEARCH = 1 << 3
     PLAYLISTS = 1 << 4
     POPOVER = 1 << 5
-    MULTIPLE = 1 << 6
+    ALBUM = 1 << 6
     NAVIGATION = 1 << 7
     SMALL = 1 << 8
-    SCROLLED = 1 << 9
-    FILTERED = 1 << 10
+    MEDIUM = 1 << 9
+    SCROLLED = 1 << 10
+    FILTERED = 1 << 11
+    FULLSCREEN = 1 << 12
 
 
 class ArtSize:
@@ -79,6 +81,7 @@ class SidebarContent:
     DEFAULT = 0
     GENRES = 1
     ARTISTS = 2
+    PERFOMERS = 3
 
 
 class SelectionListMask:
@@ -89,7 +92,7 @@ class SelectionListMask:
     GENRE = 1 << 5
     PLAYLISTS = 1 << 6
     COMPILATIONS = 1 << 7
-    ALL_ARTISTS = 1 << 8
+    ARTISTS_VIEW = 1 << 8
 
 
 class Shuffle:
