@@ -43,7 +43,7 @@ class RadioPlayer(BasePlayer):
         if Gio.NetworkMonitor.get_default().get_network_available():
             try:
                 if not App().scanner.is_locked():
-                    App().window.container.pulse(True)
+                    App().window.container.progress.pulse(True)
                 self.__current = track
                 parser = TotemPlParser.Parser.new()
                 parser.connect("entry-parsed", self.__on_entry_parsed,
@@ -80,7 +80,7 @@ class RadioPlayer(BasePlayer):
             self.emit("status-changed")
         else:
             self.emit("current-changed")
-            App().window.container.pulse(False)
+            App().window.container.progress.pulse(False)
 
     def __on_parse_finished(self, parser, result, track, play):
         """
@@ -93,7 +93,7 @@ class RadioPlayer(BasePlayer):
         # Only start playing if context always True
         if self.__current == track:
             self.__start_playback(track, play)
-            App().window.container.pulse(False)
+            App().window.container.progress.pulse(False)
 
     def __on_entry_parsed(self, parser, uri, metadata, track, play):
         """
