@@ -82,6 +82,8 @@ class ShufflePlayer(BasePlayer):
             Play a new random track if not already playing
             @param party as bool
         """
+        if party == self.__is_party:
+            return
         self.__is_party = party
         self.reset_history()
 
@@ -106,8 +108,8 @@ class ShufflePlayer(BasePlayer):
         else:
             # We want current album to continue playback
             self._albums = [self._current_track.album]
-            self.set_next()
-            self.set_prev()
+        self.set_next()
+        self.set_prev()
         self.emit("party-changed", party)
 
     def set_party_ids(self):
