@@ -36,7 +36,6 @@ class ToolbarInfo(Gtk.Bin, InformationController):
         builder.add_from_resource("/org/gnome/Lollypop/ToolbarInfo.ui")
         builder.connect_signals(self)
         self.__timeout_id = None
-        self.__mini = False
         self.__width = 0
 
         self._infobox = builder.get_object("info")
@@ -58,6 +57,11 @@ class ToolbarInfo(Gtk.Bin, InformationController):
         App().art.connect("radio-artwork-changed", self.__update_logo)
         self.connect("button-press-event", self.__on_button_press_event)
         self.connect("button-release-event", self.__on_button_release_event)
+        self.__gesture = Gtk.GestureLongPress.new(self)
+        self.__gesture.connect("pressed", self.__on_gesture_pressed)
+        # We want to get release event after gesture
+        self.__gesture.set_propagation_phase(Gtk.PropagationPhase.CAPTURE)
+        self.__gesture.set_button(0)
 
     def do_get_preferred_width(self):
         """
@@ -83,22 +87,13 @@ class ToolbarInfo(Gtk.Bin, InformationController):
 
     def set_mini(self, mini):
         """
-            Set mini mode
+            Show/hide
             @param mini as bool
         """
-        self.__mini = mini
-        try:
-            window = self._infobox.get_window()
-            if window is None:
-                return
-            if mini:
-                self._artwork.hide()
-                window.set_cursor(Gdk.Cursor(Gdk.CursorType.LEFT_PTR))
-            else:
-                self._artwork.show()
-                window.set_cursor(Gdk.Cursor(Gdk.CursorType.HAND2))
-        except:
-            Logger.warning(_("You are using a broken cursor theme!"))
+        if mini:
+            self.hide()
+        else:
+            self.show()
 
     def on_current_changed(self, player):
         """
@@ -115,10 +110,7 @@ class ToolbarInfo(Gtk.Bin, InformationController):
         """
             Show hand cursor over
         """
-        if self.__mini:
-            return
         try:
-            self._artwork.show()
             eventbox.get_window().set_cursor(Gdk.Cursor(Gdk.CursorType.HAND2))
         except:
             Logger.warning(_("You are using a broken cursor theme!"))
@@ -142,47 +134,64 @@ class ToolbarInfo(Gtk.Bin, InformationController):
             @param name as str
         """
         if App().player.current_track.album_artist == name:
-            pixbuf = App().art.get_radio_artwork(name, self.art_size)
+            pixbuf = App().art.get_radio_artwork(
+                name, self.art_size, self.art_size)
             self._artwork.set_from_surface(pixbuf)
 
+    def __popup_menu(self):
+        """
+            Show contextual menu
+        """
+        if App().window.is_adaptive or not self._artwork.get_visible():
+            return
+        from lollypop.pop_menu import ToolbarMenu
+        menu = ToolbarMenu(App().player.current_track)
+        if App().player.current_track.id >= 0:
+            from lollypop.pop_menu import TrackMenuPopover
+            popover = TrackMenuPopover(App().player.current_track, menu)
+            popover.set_relative_to(self._infobox)
+        elif App().player.current_track.id == Type.RADIOS:
+            popover = Popover.new_from_model(self._infobox, menu)
+        popover.popup()
+
     def __on_button_press_event(self, widget, event):
         """
-            Block event on button 3
+            Handle right click
             @param widget as Gtk.Widget
             @param event as Gdk.Event
         """
         if event.button == 3:
+            self.__popup_menu()
             return True
 
     def __on_button_release_event(self, widget, event):
         """
-            Show current track menu
+            Handle buttons
             @param widget as Gtk.Widget
             @param event as Gdk.Event
         """
-        if self.__mini:
+        if App().window.is_adaptive or not self._artwork.get_visible():
             return
-        if event.button == 1:
-            if App().player.current_track.id == Type.RADIOS:
-                from lollypop.pop_tunein import TuneinPopover
-                popover = TuneinPopover()
-                popover.populate()
-            elif App().player.current_track.id is not None:
-                from lollypop.pop_information import InformationPopover
-                popover = InformationPopover()
-                popover.populate()
-            popover.set_relative_to(self._infobox)
-            popover.popup()
-        else:
-            from lollypop.pop_menu import ToolbarMenu
-            menu = ToolbarMenu(App().player.current_track)
-            if App().player.current_track.id >= 0:
-                from lollypop.pop_menu import TrackMenuPopover
-                popover = TrackMenuPopover(App().player.current_track, menu)
-                popover.set_relative_to(self._infobox)
-            elif App().player.current_track.id == Type.RADIOS:
-                popover = Popover.new_from_model(self._infobox, menu)
-            popover.popup()
+        if App().player.current_track.id == Type.RADIOS:
+            from lollypop.pop_tunein import TuneinPopover
+            popover = TuneinPopover()
+            popover.populate()
+        elif App().player.current_track.id is not None:
+            from lollypop.pop_information import InformationPopover
+            popover = InformationPopover()
+            popover.populate()
+        popover.set_relative_to(self._infobox)
+        popover.popup()
+        return True
+
+    def __on_gesture_pressed(self, gesture, x, y):
+        """
+            Show current track menu
+            @param gesture as Gtk.GestureLongPress
+            @param x as int
+            @param y as int
+        """
+        self.__popup_menu()
 
     def __on_realize(self, toolbar):
         """
